import React from 'react'
import moment from 'moment'
import { Paginator } from './paginator'
import { SymbolBackward, SymbolForward } from './svgs'
import { dateFilter, truncate, striptags } from '../utils'

function relURL(filename, dir_) {
  let dir = dir_
  if (filename.substr(0, 1) === '/' || filename.match('://')) return filename
  if (dir.substr(0, 1) !== '/') dir = `/${dir}`
  if (filename.match(/\/$/)) return dir + filename
  if (dir.match(/\/$/)) return dir + filename
  return `${dir}/${filename}`
}

export function List({ subtags, tag, content, metadata, file, config }) {
  return (
    <div id="content" className="container">
      <div className="section">
        <div className="row">
          <div className="col">
            <a className="breadcrumb">{tag.text}</a>
            {subtags &&
              subtags.map(subtag => (
                <React.Fragment key={subtag.url}>
                  {' '}
                  <a href={`${config.baseurl}/${subtag.url}`} className="chip">
                    {subtag.text}
                  </a>
                </React.Fragment>
              ))}
          </div>
        </div>
        <div className="row">
          {content.map(page => (
            <div className="col s12 m6 l4" key={page.file}>
              <div className="block article">
                <a href={`${config.baseurl}/${page.file}`}>
                  <div
                    style={{
                      height: 120,
                      backgroundImage: page.metadata.image
                        ? `url('${config.baseurl}${relURL(
                            page.metadata.image,
                            page.file,
                          )}')`
                        : undefined,
                    }}
                    className="leadimage light-blue darken-2"
                  ></div>
                </a>
                <div className="head-title">
                  <a href={`${config.baseurl}/${page.file}`}>
                    <h5 className="center">{page.metadata.title}</h5>
                  </a>
                </div>
                <div style={{ padding: '0px 10px' }} className="head-perex">
                  {page.metadata.perex
                    ? page.metadata.perex
                    : page.metadata.perex_e
                    ? truncate(page.metadata.perex_e)
                    : page.content
                    ? truncate(striptags(page.content))
                    : null}
                </div>
                <div className="clear"></div>
                <div style={{ padding: 10 }} className="head-info">
                  <span
                    style={{
                      color: '#a2a2a2',
                      textAlign: 'left',
                      display: 'inline-block',
                      width: '75%',
                    }}
                  >
                    {dateFilter(page.metadata.published, 'D. M. YYYY')} napsal
                    {page.metadata.author.gender === 'F' ? 'a' : ''}{' '}
                    {page.metadata.author.name}
                  </span>
                  <a
                    style={{
                      textAlign: 'right',
                      display: 'inline-block',
                      width: '25%',
                    }}
                    href={`${config.baseurl}/${page.file}`}
                  >
                    Číst&nbsp;dál
                  </a>
                </div>
              </div>
            </div>
          ))}
        </div>
        <Paginator metadata={metadata} file={file} config={config} />
      </div>

      <div className="hide-on-small-only">
        {metadata.prevurl && (
          <div style={{ left: 0 }} className="sidelink sidelink-l">
            <a href={`${config.baseurl}/${metadata.prevurl}`}>
              <div>
                <SymbolBackward />
              </div>
            </a>
          </div>
        )}
        {metadata.nexturl && (
          <div style={{ right: 0 }} className="sidelink sidelink-r">
            <a href={`${config.baseurl}/${metadata.nexturl}`}>
              <div>
                <SymbolForward />
              </div>
            </a>
          </div>
        )}
      </div>

      <script
        dangerouslySetInnerHTML={{
          __html: `
    (function($) {
      var onresize = function(){
        // equalize article sizes
        $(".head-perex").height("auto");
        var maxHeight = 0;
        $(".head-perex").each(function(){
          if ($(this).height() > maxHeight) { maxHeight = $(this).height(); }
        });
        $(".head-perex").height(maxHeight);

        $(".head-title").height("auto");
        maxHeight = 0;
        $(".head-title").each(function(){
          if ($(this).height() > maxHeight) { maxHeight = $(this).height(); }
        });
        $(".head-title").height(maxHeight);

        $(".head-info").height("auto");
        maxHeight = 0;
        $(".head-info").each(function(){
          if ($(this).height() > maxHeight) { maxHeight = $(this).height(); }
        });
        $(".head-info").height(maxHeight);

        // Sidelink icons of same size
        $(".sidelink-icon").css("top",$(window).height()/2);
      };
      $(window).resize(onresize);
      $(document).load(onresize);
      $(document).ready(onresize);
      $(document).keyup(function(e) {
        if($("#search-overlay").hasClass("shown")) return;
        ${
          metadata.nexturl
            ? `if(e.key == "ArrowRight") window.location = "${config.baseurl}/${metadata.nexturl}";`
            : ''
        }
        ${
          metadata.prevurl
            ? `if(e.key == "ArrowLeft") window.location = "${config.baseurl}/${metadata.prevurl}"`
            : ''
        }
      });
    })(jQuery);
    `,
        }}
      />
    </div>
  )
}
