import moment from 'moment'

export function dateFilter(date, format) {
  let result
  const errs = []
  const args = []
  let obj
  Array.prototype.push.apply(args, arguments)
  try {
    obj = moment.utc(date)
  } catch (err) {
    errs.push(err)
  }
  if (obj) {
    try {
      if (obj[format] && typeof obj[format] === 'function') {
        result = obj[format].apply(obj, args.slice(2))
      } else {
        result = obj.format(format)
      }
    } catch (err) {
      errs.push(err)
    }
  }

  if (errs.length) {
    return errs.join('\n')
  }
  return result
}

function normalize(value, defaultValue) {
  if (value === null || value === undefined || value === false) {
    return defaultValue
  }
  return value
}

export function truncate(input_, length_, killwords, end) {
  let input = normalize(input_, '')
  const length = length_ || 255

  if (input.length <= length) {
    return input
  }

  if (killwords) {
    input = input.substring(0, length)
  } else {
    let idx = input.lastIndexOf(' ', length)
    if (idx === -1) {
      idx = length
    }

    input = input.substring(0, idx)
  }

  input += end !== undefined && end !== null ? end : '...'
  return input
}

function trim(str) {
  return str.replace(/^\s*|\s*$/g, '')
}

export function striptags(input_, preserveLinebreaks) {
  const input = normalize(input_, '')
  const tags = /<\/?([a-z][a-z0-9]*)\b[^>]*>|<!--[\s\S]*?-->/gi
  const trimmedInput = trim(input.replace(tags, ''))
  let res = ''
  if (preserveLinebreaks) {
    res = trimmedInput
      .replace(/^ +| +$/gm, '') // remove leading and trailing spaces
      .replace(/ +/g, ' ') // squash adjacent spaces
      .replace(/(\r\n)/g, '\n') // normalize linebreaks (CRLF -> LF)
      .replace(/\n\n\n+/g, '\n\n') // squash abnormal adjacent linebreaks
  } else {
    res = trimmedInput.replace(/\s+/gi, ' ')
  }
  return res
}
